@@ -6,6 +6,7 @@ This module a thin wrapper around the CKAN's action API.
 """
 
 import urllib2
+import urllib
 import json
 
 class CKANAPIError(Exception):
@@ -173,8 +174,9 @@ class RemoteCKAN(object):
                 "use of context parameter, use apikey instead")
         url, data, headers = prepare_action(action, data_dict,
                                             apikey or self.apikey)
-        status, response = self._request_fn(self.address + url, data, headers)
-        return reverse_apicontroller_action(status, response)
+        url = urllib.basejoin(self.address, url)
+        status, response = self._request_fn(url, data, headers)
+        return reverse_apicontroller_action(url, status, response)
 
     def _request_fn(self, url, data, headers):
         req = urllib2.Request(url, data, headers)
@@ -215,8 +217,8 @@ class TestAppCKAN(object):
                 "use of context parameter, use apikey instead")
         url, data, headers = prepare_action(action, data_dict,
                                             apikey or self.apikey)
-        r = self.test_app.post(url, data, headers, expect_errors=True)
-        return reverse_apicontroller_action(r.status, r.body)
+        r = self.test_app.post('/' + url, data, headers, expect_errors=True)
+        return reverse_apicontroller_action(url, r.status, r.body)
 
 
 def prepare_action(action, data_dict=None, apikey=None):
@@ -231,11 +233,11 @@ def prepare_action(action, data_dict=None, apikey=None):
         apikey = str(apikey)
         headers['X-CKAN-API-Key'] = apikey
         headers['Authorization'] = apikey
-    url = '/api/action/' + action
+    url = 'api/action/' + action
     return url, data, headers
 
 
-def reverse_apicontroller_action(status, response):
+def reverse_apicontroller_action(url, status, response):
     """
     Make an API call look like a direct action call by reversing the
     exception -> HTTP response translation that ApiController.action does
@@ -269,4 +271,4 @@ def reverse_apicontroller_action(status, response):
         raise NotAuthorized(err)
 
     # don't recognize the error
-    raise CKANAPIError(response, status)
+    raise CKANAPIError(url, status, response)
